@@ -2,9 +2,14 @@ var group__DRV__ENETPHY =
 [
     [ "Generic PHY", "group__ENETPHY__GENERIC__PHY.html", null ],
     [ "TI DP83822 PHY", "group__ENETPHY__DP83822.html", "group__ENETPHY__DP83822" ],
+    [ "TI DP83826 PHY", "group__ENETPHY__DP83826.html", "group__ENETPHY__DP83826" ],
     [ "TI DP83867 PHY", "group__ENETPHY__DP83867.html", "group__ENETPHY__DP83867" ],
     [ "TI DP83869 PHY", "group__ENETPHY__DP83869.html", "group__ENETPHY__DP83869" ],
-    [ "VSC8514 PHY", "group__ENETPHY__VSC8514.html", "group__ENETPHY__VSC8514" ],
+    [ "TI DP83TC812 PHY", "group__ENETPHY__DP83TC812.html", "group__ENETPHY__DP83TC812" ],
+    [ "TI DP83TG720 PHY", "group__ENETPHY__DP83TG720.html", "group__ENETPHY__DP83TG720" ],
+    [ "TI DP83TG721 PHY", "group__ENETPHY__DP83TG721.html", "group__ENETPHY__DP83TG721" ],
+    [ "TI PHY COMMON", "group__PHY__COMMON__H.html", "group__PHY__COMMON__H" ],
+    [ "TI generic_phy PHY", "group__ENETPHY__generic__phy.html", "group__ENETPHY__generic__phy" ],
     [ "EnetPhy_Version", "structEnetPhy__Version.html", [
       [ "oui", "structEnetPhy__Version.html#ae508bfdc1dffd61a5dc5ac04fd9c52a1", null ],
       [ "model", "structEnetPhy__Version.html#a6761be25acfe02923d1569b74ce1a25d", null ],
@@ -29,6 +34,7 @@ var group__DRV__ENETPHY =
       [ "nwayCaps", "structEnetPhy__Cfg.html#a326170d15fbd5660cd42f4058afca30b", null ],
       [ "mdixEn", "structEnetPhy__Cfg.html#af6ab0be3244688975ba5b1da98f9af54", null ],
       [ "isStrapped", "structEnetPhy__Cfg.html#aef3400ed350c5e78510e7ea6536b49ca", null ],
+      [ "isIsolateStateReq", "structEnetPhy__Cfg.html#a13e073030c36adfcfb2578f3e6aab261", null ],
       [ "loopbackEn", "structEnetPhy__Cfg.html#a85bbc546f6fc38ede1e120db880eb27b", null ],
       [ "masterMode", "structEnetPhy__Cfg.html#ab3c6228827b13bc92c726e17f95db41e", null ],
       [ "extClkSource", "structEnetPhy__Cfg.html#a0fbd51a9e60e0b019a8d7c96f57464c7", null ],
@@ -38,12 +44,12 @@ var group__DRV__ENETPHY =
       [ "extendedCfgSize", "structEnetPhy__Cfg.html#ae3048f34b725dbeec14676249aa3ddb7", null ]
     ] ],
     [ "EnetPhy_Mdio", "structEnetPhy__Mdio.html", [
-      [ "isAlive", "structEnetPhy__Mdio.html#a09e3091bb14ac724cb7a3c80ac02a69e", null ],
-      [ "isLinked", "structEnetPhy__Mdio.html#a7072ad80bbb047d3db68e756b51b00d2", null ],
-      [ "readC22", "structEnetPhy__Mdio.html#ac14429bc8731f897697a71698c77972a", null ],
-      [ "writeC22", "structEnetPhy__Mdio.html#ac88084c3081f99b055586cca0a7fc5ca", null ],
-      [ "readC45", "structEnetPhy__Mdio.html#aa4bb985e7fec55d2023b2f1dd755daff", null ],
-      [ "writeC45", "structEnetPhy__Mdio.html#ab117ff9dfb835fcb913c3751ee29b7d7", null ]
+      [ "isAlive", "structEnetPhy__Mdio.html#a1b052cda4dfe8479626db2962b638ef7", null ],
+      [ "isLinked", "structEnetPhy__Mdio.html#a0e81c881f6411271e22200c953495679", null ],
+      [ "readC22", "structEnetPhy__Mdio.html#a90a400312241d823da5e4e2180321743", null ],
+      [ "writeC22", "structEnetPhy__Mdio.html#adf8aff6f641f4989d9e86b320644d3b0", null ],
+      [ "readC45", "structEnetPhy__Mdio.html#ae5726adc4dc388d402253c819845c7b3", null ],
+      [ "writeC45", "structEnetPhy__Mdio.html#a548a70b4056807f902199a0c0ed448cc", null ]
     ] ],
     [ "EnetPhy_State", "structEnetPhy__State.html", [
       [ "fsmState", "structEnetPhy__State.html#a7a1b87ae30afd4973a78214cc587ff5f", null ],
@@ -73,9 +79,10 @@ var group__DRV__ENETPHY =
       [ "group", "structEnetPhy__Obj.html#a598b95b4f8f6e5d6cb9d09fdddedf808", null ],
       [ "addr", "structEnetPhy__Obj.html#a3cb346e8055e88a8bad2abcb6e529a3a", null ],
       [ "reqLinkCaps", "structEnetPhy__Obj.html#ad277b7ca1134d1809919408a5cfaf413", null ],
-      [ "hDrv", "structEnetPhy__Obj.html#a346d74f90fdca0024cafccb2563047b1", null ],
+      [ "hDrvIf", "structEnetPhy__Obj.html#a850453b51829db99fd0ce5b7eb893e0e", null ],
       [ "magic", "structEnetPhy__Obj.html#ab09f1f4d15d40dae95f9246946646308", null ],
-      [ "mdioArgs", "structEnetPhy__Obj.html#ad5381dcfc88775aea033df40e7610d98", null ]
+      [ "mdioArgs", "structEnetPhy__Obj.html#a85e4d163e1873aafc8e19073fa494590", null ],
+      [ "priv", "structEnetPhy__Obj.html#a7be549959efd1b2ac45387c2dea1d76f", null ]
     ] ],
     [ "ENETPHY_IS_ADDR_VALID", "group__DRV__ENETPHY.html#gad646043be1e207b7fb6ba1bae5371c4a", null ],
     [ "ENETPHY_BIT", "group__DRV__ENETPHY.html#ga42a23019279db985de2fd7bd5c4a6b32", null ],
@@ -89,6 +96,7 @@ var group__DRV__ENETPHY =
     [ "ENETPHY_EALLOC", "group__DRV__ENETPHY.html#ga3f04871b7819dfdd4c751d6f3da72eb8", null ],
     [ "ENETPHY_EPERM", "group__DRV__ENETPHY.html#gaf000eee87b30b560efb240b563aba84a", null ],
     [ "ENETPHY_ENOTSUPPORTED", "group__DRV__ENETPHY.html#gab2ddd9c4da3de62bd1ec4f91c1423c04", null ],
+    [ "ENETPHY_EUNAVAILABLE", "group__DRV__ENETPHY.html#gaa9baf8e858b6b7be16eaa576f2b96f6a", null ],
     [ "ENETPHY_LINK_CAP_HD10", "group__DRV__ENETPHY.html#ga3dc4194bba86e7f9a793ebdf9d963f96", null ],
     [ "ENETPHY_LINK_CAP_FD10", "group__DRV__ENETPHY.html#ga8888e695def8844c5b265fdfe0e98376", null ],
     [ "ENETPHY_LINK_CAP_HD100", "group__DRV__ENETPHY.html#ga0506e3cd213458b8b9211ac04bc0eeca", null ],
@@ -104,8 +112,8 @@ var group__DRV__ENETPHY =
     [ "ENETPHY_INVALID_PHYADDR", "group__DRV__ENETPHY.html#gaac99db2dbc6b1607f75384f3aa15fdba", null ],
     [ "ENETPHY_TIMEOUT_WAIT_FOREVER", "group__DRV__ENETPHY.html#gab83ed97712deb9e0c9fbb57352798bd6", null ],
     [ "ENETPHY_TIMEOUT_NO_WAIT", "group__DRV__ENETPHY.html#ga9bc19f2b33c4f1e9bdd6f7cfae87f6f8", null ],
+    [ "Mdio_Obj", "group__DRV__ENETPHY.html#gaa1d96cf32f75f046e6c14d4296ba23ab", null ],
     [ "EnetPhy_MdioHandle", "group__DRV__ENETPHY.html#ga716230b8d453cbadf076c6d2e6db6468", null ],
-    [ "EnetPhyDrv_Handle", "group__DRV__ENETPHY.html#gae2adc95bf3a449171fbe12916ac9ec6d", null ],
     [ "EnetPhy_Handle", "group__DRV__ENETPHY.html#ga321b990b312722b35a86cf9d09be4e48", null ],
     [ "EnetPhy_Magic", "group__DRV__ENETPHY.html#gaf3c210740d0f86ebaee58dafeaf00ae7", [
       [ "ENETPHY_MAGIC", "group__DRV__ENETPHY.html#ggaf3c210740d0f86ebaee58dafeaf00ae7ae49dede0f79dbe62dbc48509621c3d27", null ],
@@ -146,25 +154,43 @@ var group__DRV__ENETPHY =
       [ "ENETPHY_FSM_STATE_NWAY_WAIT", "group__DRV__ENETPHY.html#ggae587cb11639bc55116a9b434ed06694caafabde2c05566301bd24b77edb6a5abc", null ],
       [ "ENETPHY_FSM_STATE_LINK_WAIT", "group__DRV__ENETPHY.html#ggae587cb11639bc55116a9b434ed06694ca86db66aa51421cb96c96da03aa017457", null ],
       [ "ENETPHY_FSM_STATE_LINKED", "group__DRV__ENETPHY.html#ggae587cb11639bc55116a9b434ed06694cac9559b0574ad03dbed3a3982396d897c", null ],
-      [ "ENETPHY_FSM_STATE_LOOPBACK", "group__DRV__ENETPHY.html#ggae587cb11639bc55116a9b434ed06694ca4c8c9948975b9279ee6bd7b0dbda3722", null ]
+      [ "ENETPHY_FSM_STATE_LOOPBACK", "group__DRV__ENETPHY.html#ggae587cb11639bc55116a9b434ed06694ca4c8c9948975b9279ee6bd7b0dbda3722", null ],
+      [ "ENETPHY_FSM_STATE_ISOLATE", "group__DRV__ENETPHY.html#ggae587cb11639bc55116a9b434ed06694caef3b0b24050475f1042fa95e6940121b", null ]
     ] ],
     [ "EnetPhy_initCfg", "group__DRV__ENETPHY.html#gaff5006a4c712434d31f67b3d5d4b3bf9", null ],
     [ "EnetPhy_setExtendedCfg", "group__DRV__ENETPHY.html#ga5f7008641bf565765c557f55756937a4", null ],
-    [ "EnetPhy_open", "group__DRV__ENETPHY.html#ga3f5ded0b10bca14051e55f1a01402aaf", null ],
+    [ "EnetPhy_open", "group__DRV__ENETPHY.html#ga1d8cebac9cf8a645b504894220106215", null ],
     [ "EnetPhy_close", "group__DRV__ENETPHY.html#ga1d69a2547cc8cb17c9ccd397ac164378", null ],
     [ "EnetPhy_tick", "group__DRV__ENETPHY.html#ga82babbc2e9c65ac5dc541c6fc8e33ca3", null ],
     [ "EnetPhy_getId", "group__DRV__ENETPHY.html#ga1f5f88ec72a5d6b371a7954131f791fb", null ],
     [ "EnetPhy_isAlive", "group__DRV__ENETPHY.html#ga44228766624b60da80c50ec2525107e2", null ],
     [ "EnetPhy_isLinked", "group__DRV__ENETPHY.html#gae8c9df0eace5f8b6b809176a0c420cda", null ],
     [ "EnetPhy_getLinkCfg", "group__DRV__ENETPHY.html#ga67859143637d0b09b8d3249774c1c002", null ],
-    [ "EnetPhy_readReg", "group__DRV__ENETPHY.html#ga4363f16c4a81228f512145ab28e88c16", null ],
-    [ "EnetPhy_writeReg", "group__DRV__ENETPHY.html#ga376e5c22e0dd697ab734b901b2f8b82b", null ],
-    [ "EnetPhy_rmwReg", "group__DRV__ENETPHY.html#gabc3cb8908bfb8795d245158cf23616c4", null ],
-    [ "EnetPhy_readExtReg", "group__DRV__ENETPHY.html#ga5a3de316b5cf1d0dd52a84ac05dc6f06", null ],
-    [ "EnetPhy_writeExtReg", "group__DRV__ENETPHY.html#ga2094003a148e71b97b95168de64bae40", null ],
+    [ "EnetPhy_getLinkStatus", "group__DRV__ENETPHY.html#ga6c43a066e16bc7f2aa317376c4ec87fd", null ],
+    [ "EnetPhy_readReg", "group__DRV__ENETPHY.html#ga91edf30111d6ae795012514542e285d8", null ],
+    [ "EnetPhy_writeReg", "group__DRV__ENETPHY.html#ga5b7e4026319c8138985fe4801f26bc43", null ],
+    [ "EnetPhy_rmwReg", "group__DRV__ENETPHY.html#ga1a8b1d84f67084d34edd9b42ceb05965", null ],
+    [ "EnetPhy_readExtReg", "group__DRV__ENETPHY.html#gabdd66d8f016935402e364379ff31bcf8", null ],
+    [ "EnetPhy_writeExtReg", "group__DRV__ENETPHY.html#ga38c339c1c248304d653398e7a0a866f0", null ],
     [ "EnetPhy_rmwExtReg", "group__DRV__ENETPHY.html#gaf95e72866cee60c328592b4fc3a95943", null ],
     [ "EnetPhy_readC45Reg", "group__DRV__ENETPHY.html#gaffc3fd5abf62e9d2b0ff41869b2622ec", null ],
     [ "EnetPhy_writeC45Reg", "group__DRV__ENETPHY.html#ga2f5294c3ffcd261efce2573c32038cbd", null ],
     [ "EnetPhy_rmwC45Reg", "group__DRV__ENETPHY.html#ga0785780a87174ef9fabff8b6a49a1cb2", null ],
-    [ "EnetPhy_printRegs", "group__DRV__ENETPHY.html#ga86d2852ee8d820639c56aa26104965fc", null ]
+    [ "EnetPhy_printRegs", "group__DRV__ENETPHY.html#ga86d2852ee8d820639c56aa26104965fc", null ],
+    [ "EnetPhy_adjPtpFreq", "group__DRV__ENETPHY.html#ga1f2bbacde0de1fefe7dbf5e844324851", null ],
+    [ "EnetPhy_adjPtpPhase", "group__DRV__ENETPHY.html#ga6f49b6a8f4260ed3817279c73fcdd53e", null ],
+    [ "EnetPhy_getPtpTime", "group__DRV__ENETPHY.html#ga3d01b2f12415b08d414b11d17582efc0", null ],
+    [ "EnetPhy_setPtpTime", "group__DRV__ENETPHY.html#gaf8bb9ad3d5840e91bfe2bb840c8ee034", null ],
+    [ "EnetPhy_getPtpTxTime", "group__DRV__ENETPHY.html#gaf8cfa0f6f53343bff002f7d8e75f3fe4", null ],
+    [ "EnetPhy_getPtpRxTime", "group__DRV__ENETPHY.html#gaaab7c58d5123053eeb47966f8859fe6b", null ],
+    [ "EnetPhy_waitPtpTxTime", "group__DRV__ENETPHY.html#ga8e87a0bdd1d1939ab335cc53f5729c3d", null ],
+    [ "EnetPhy_procStatusFrame", "group__DRV__ENETPHY.html#gab8456a1df856f905983dde40b2a95d99", null ],
+    [ "EnetPhy_getStatusFrameEthHeader", "group__DRV__ENETPHY.html#gad861d859a82140f5c570acb71145f602", null ],
+    [ "EnetPhy_enablePtp", "group__DRV__ENETPHY.html#gaf5d0a5d67fe73b693efcfa6062518b9d", null ],
+    [ "EnetPhy_tickDriver", "group__DRV__ENETPHY.html#ga62ccd584b1844929926fb9554c95683d", null ],
+    [ "EnetPhy_enableEventCapture", "group__DRV__ENETPHY.html#ga0dc85abb0de79855f3f8e3b26f48ffb6", null ],
+    [ "EnetPhy_enableTriggerOutput", "group__DRV__ENETPHY.html#ga65171003450b027831a898c7c2dfe693", null ],
+    [ "EnetPhy_getEventTs", "group__DRV__ENETPHY.html#ga6a5b68a158188d891346fb6b74096b31", null ],
+    [ "EnetPhy_configMediaClock", "group__DRV__ENETPHY.html#gab3ff4a61a3baece654a738afa369cd4a", null ],
+    [ "EnetPhy_nudgeCodecClock", "group__DRV__ENETPHY.html#ga9535e9ca77ebdba36a29c48ee1481bf5", null ]
 ];
\ No newline at end of file
