@@ -3,11 +3,15 @@ var group__DRV__HSMCLIENT__UTILS__MODULE =
     [ "SOC_TYPE_AM263X", "group__DRV__HSMCLIENT__UTILS__MODULE.html#ga4b3ff4638f3cdf4a6129674923cec70c", null ],
     [ "SOC_TYPE_AM263P", "group__DRV__HSMCLIENT__UTILS__MODULE.html#ga11a3ead3088a503966a67d5b2ac35d2b", null ],
     [ "SOC_TYPE_AM273X", "group__DRV__HSMCLIENT__UTILS__MODULE.html#gaaebee40229266b449924f7197284fb23", null ],
+    [ "SOC_TYPE_AWR294X", "group__DRV__HSMCLIENT__UTILS__MODULE.html#gae98cbef478fc84802c2c778e067254b3", null ],
+    [ "SOC_TYPE_F29H85x", "group__DRV__HSMCLIENT__UTILS__MODULE.html#ga5a1b50ae8e38bf254a810ad38613f9c6", null ],
+    [ "SOC_TYPE_AM261x", "group__DRV__HSMCLIENT__UTILS__MODULE.html#ga244938598fe87fb5d2c16b7f19a48977", null ],
     [ "NUM_SOC_TYPE", "group__DRV__HSMCLIENT__UTILS__MODULE.html#ga108569bd5236f2f99f1a0863299833e3", null ],
     [ "DEVICE_TYPE_HS_FS", "group__DRV__HSMCLIENT__UTILS__MODULE.html#ga5bcf343d5b2f82fbfda9bfa7dcb568b8", null ],
     [ "DEVICE_TYPE_HS_SE", "group__DRV__HSMCLIENT__UTILS__MODULE.html#gaa154a8f1077fd780cc1b90f2e72cba91", null ],
     [ "HSM_V1", "group__DRV__HSMCLIENT__UTILS__MODULE.html#ga31bfbc0ce1c92abb6b95b617f24010ef", null ],
     [ "BIN_TYPE_STANDARD", "group__DRV__HSMCLIENT__UTILS__MODULE.html#ga58a57a20dd1fc1503fa83300d706cd10", null ],
     [ "BIN_TYPE_CUSTOM", "group__DRV__HSMCLIENT__UTILS__MODULE.html#gae5d05320dff52f510ba5dc5858ae0256", null ],
+    [ "BIN_TYPE_OTPKW", "group__DRV__HSMCLIENT__UTILS__MODULE.html#ga51af79d782018b7298836221bf4fbd70", null ],
     [ "HsmClient_parseVersion", "group__DRV__HSMCLIENT__UTILS__MODULE.html#ga1bb7314746335adfeeb9a8c05bdc4667", null ]
 ];
\ No newline at end of file
