@@ -21,6 +21,8 @@ var group__DRV__PINMUX__MODULE =
     [ "PIN_GPIO_R5SS0_1", "group__DRV__PINMUX__MODULE.html#gab0f94b102d18461decab3bde1f1b3362", null ],
     [ "PIN_GPIO_R5SS1_0", "group__DRV__PINMUX__MODULE.html#gabae218c9569d281e445c2c5bf95f9b09", null ],
     [ "PIN_GPIO_R5SS1_1", "group__DRV__PINMUX__MODULE.html#ga37240bf87704e2b7ae4fd33df201c562", null ],
+    [ "PIN_QUAL_GRP_MAX_INDEX", "group__DRV__PINMUX__MODULE.html#ga7a626026bc7618a64e6bbb65337cf196", null ],
+    [ "PIN_QUAL_GROUP_CFG_START", "group__DRV__PINMUX__MODULE.html#ga4421720954fb63180cfaf1b617c8bfdd", null ],
     [ "PIN_QUAL_SYNC", "group__DRV__PINMUX__MODULE.html#ga874babb4ec9177034fb9c4e993203580", null ],
     [ "PIN_QUAL_3SAMPLE", "group__DRV__PINMUX__MODULE.html#ga1ea788bfe425918f79df3122ccdbcd20", null ],
     [ "PIN_QUAL_6SAMPLE", "group__DRV__PINMUX__MODULE.html#ga7d08ea2b9da20e6abb3618526be95af2", null ],
@@ -173,5 +175,8 @@ var group__DRV__PINMUX__MODULE =
     [ "PIN_TMS", "group__DRV__PINMUX__MODULE.html#ga45867e53ab8e918075929ec92ae5272c", null ],
     [ "PIN_TCK", "group__DRV__PINMUX__MODULE.html#gadd84722750f76c77b70b9fb01dabfad2", null ],
     [ "PIN_QSPI_CLKLB", "group__DRV__PINMUX__MODULE.html#gac653eb473be30322d2d71019947323e0", null ],
-    [ "Pinmux_config", "group__DRV__PINMUX__MODULE.html#ga416b7b8c652a8c2abc8a5ce6510f7b4d", null ]
+    [ "Pinmux_config", "group__DRV__PINMUX__MODULE.html#ga416b7b8c652a8c2abc8a5ce6510f7b4d", null ],
+    [ "Pinmux_qualPeriodConfig", "group__DRV__PINMUX__MODULE.html#ga8756c740ddde083e1c972be4f6f4873e", null ],
+    [ "Pinmux_enableUserMode", "group__DRV__PINMUX__MODULE.html#ga341861797b2125f48233b896a2ec048f", null ],
+    [ "Pinmux_disableUserMode", "group__DRV__PINMUX__MODULE.html#ga3f5466ec2fff23c5a32558a2c35ec51d", null ]
 ];
\ No newline at end of file
