@@ -4,5 +4,6 @@ var group__KERNEL__DPL__CPU =
       [ "cpuID", "structCSL__ArmR5CPUInfo.html#ab61fb01301da2a638345c5cb8be309ca", null ],
       [ "grpId", "structCSL__ArmR5CPUInfo.html#aa1632ed76b18974e7d5bef84ea28031c", null ]
     ] ],
-    [ "CSL_armR5GetCpuID", "group__KERNEL__DPL__CPU.html#ga37f9706ca6c8fc4baef0985ad2c9e042", null ]
+    [ "CSL_armR5GetCpuID", "group__KERNEL__DPL__CPU.html#ga37f9706ca6c8fc4baef0985ad2c9e042", null ],
+    [ "CSL_armR5SetWFIMode", "group__KERNEL__DPL__CPU.html#gaa7c023541e1463bdcc8c348398a47a8b", null ]
 ];
\ No newline at end of file
