@@ -1,9 +1,5 @@
 var group__KERNEL__DPL__EVENT =
 [
-    [ "EventP_Object", "structEventP__Object.html", [
-      [ "rsv", "structEventP__Object.html#a9079355584ad69c174e5d574ccfa590e", null ]
-    ] ],
-    [ "EventP_OBJECT_SIZE_MAX", "group__KERNEL__DPL__EVENT.html#ga8c709fd86eff4c7a808a5a9586d1e858", null ],
     [ "EventP_construct", "group__KERNEL__DPL__EVENT.html#gafca8272287bdaa6a6e5cc7b29f52105e", null ],
     [ "EventP_destruct", "group__KERNEL__DPL__EVENT.html#gae4b3c278316a067d41e141591630e594", null ],
     [ "EventP_waitBits", "group__KERNEL__DPL__EVENT.html#ga49665ab39513aebef09c689c6e1c34cd", null ],
