@@ -5,12 +5,12 @@ var group__KERNEL__DPL__QUEUE =
       [ "prev", "structQueueP__Elem.html#a3ed3c75394476bbec3f788d652816fcd", null ]
     ] ],
     [ "QueueP_Object", "structQueueP__Object.html", [
-      [ "rsv", "structQueueP__Object.html#a7924cf80de26b006f338167c4ae70e45", null ]
+      [ "queueHndl", "structQueueP__Object.html#a950631ac5b7e7af1fa1716db865755a4", null ]
     ] ],
+    [ "QueueP_OBJECT_SIZE_MAX", "group__KERNEL__DPL__QUEUE.html#ga309f611d4e528fd7e69ddb3425b55c78", null ],
     [ "QueueP_NOTEMPTY", "group__KERNEL__DPL__QUEUE.html#ga096097976f4f04679dea543cc02d95ba", null ],
     [ "QueueP_EMPTY", "group__KERNEL__DPL__QUEUE.html#ga792e3ce982e3508f74d4cc6a5daeb76e", null ],
-    [ "QueueP_OBJECT_SIZE_MAX", "group__KERNEL__DPL__QUEUE.html#ga309f611d4e528fd7e69ddb3425b55c78", null ],
-    [ "QueueP_Handle", "group__KERNEL__DPL__QUEUE.html#ga14ac2d80a301002c91856418a07fd3c0", null ],
+    [ "QueueP_Handle", "group__KERNEL__DPL__QUEUE.html#ga754de0b935051f0bcad7135395fc989d", null ],
     [ "QueueP_create", "group__KERNEL__DPL__QUEUE.html#ga8d7dd57b12b4c10d845abc054a6cede2", null ],
     [ "QueueP_delete", "group__KERNEL__DPL__QUEUE.html#ga706c699c3b0f6acfeb4d33a93b0c30fc", null ],
     [ "QueueP_get", "group__KERNEL__DPL__QUEUE.html#ga9c07c2f85839bf3649b5905accdb018a", null ],
