@@ -1,8 +1,7 @@
 var group__SDL__STC__API =
 [
-    [ "DCC Enumerated Data Types", "group__SDL__DCC__ENUM.html", "group__SDL__DCC__ENUM" ],
     [ "STC Data Structures", "group__SDL__STC__DATASTRUCT.html", "group__SDL__STC__DATASTRUCT" ],
-    [ "STC Enumerated Data Types", "group__SDL__STC__ENUM.html", null ],
+    [ "STC Enumerated Data Types", "group__SDL__STC__ENUM.html", "group__SDL__STC__ENUM" ],
     [ "STC Functions", "group__SDL__STC__FUNCTIONS.html", "group__SDL__STC__FUNCTIONS" ],
     [ "STC Macros", "group__SDL__STC__MACROS.html", "group__SDL__STC__MACROS" ],
     [ "stc/v0/sdl_stc.h", "stc_2v0_2sdl__stc_8h.html", null ]
